ClientDeviceAuthKeyAuthenticator

Struct ClientDeviceAuthKeyAuthenticator 

pub struct ClientDeviceAuthKeyAuthenticator {
    pub(super) client: ClientFido2,
    pub(super) store: Arc<dyn DeviceAuthKeyStore>,
}

Fields

client: ClientFido2store: Arc<dyn DeviceAuthKeyStore>

Implementations

Source

impl ClientDeviceAuthKeyAuthenticator

pub async fn create_device_auth_key( &self, client_name: String, web_vault_url: String, email: String, secret_verification_request: SecretVerificationRequest, kdf: Kdf, ) -> Result<()>

Create a device auth key by registering an unlock passkey and PRF keyset with the server. The passkey private key and metadata will be stored on the device using the provided trait implementation.

async fn assert_device_auth_key( &self, request: GetAssertionRequest, ) -> Result<DeviceAuthKeyGetAssertionResult>

Uses a device auth key to respond to the provided WebAuthn assertion request. Satisfy the given FIDO assertion request using the device auth key. The device auth key will be looked up from the ClientDeviceAuthKeyAuthenticator::store provided in the initializer.

async fn unregister_device_auth_key( &self, email: String, secret_verification_request: SecretVerificationRequest, kdf: Kdf, ) -> Result<()>

Deletes a device auth key and unregisters it from the server.